@@ -5,7 +5,7 @@
  http://libquicktime.sourceforge.net
 
  Copyright (C) 2002 Heroine Virtual Ltd.
- Copyright (C) 2002-2007 Members of the libquicktime project.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
 
  This library is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
@@ -25,8 +25,14 @@
 #ifndef	_LQT_ATOMS_H_
 #define _LQT_ATOMS_H_
 
+
+
 #pragma GCC visibility push(default)
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* Fine tuning of quicktime atoms. Use with caution */
 
 /** \defgroup atoms Fine tuning of quicktime atoms
@@ -205,6 +211,10 @@ int  lqt_set_colr(quicktime_t *file, int track, quicktime_colr_t *colr);
  */
 int  lqt_get_colr(quicktime_t *file, int track, quicktime_colr_t *colr);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #pragma GCC visibility pop
 
 #endif /* _LQT_ATOMS_H_ */
